@@ -2,7 +2,7 @@ package Test2::Compare::Delta;
 use strict;
 use warnings;
 
-our $VERSION = '0.000070';
+our $VERSION = '0.000118';
 
 use Test2::Util::HashBase qw{verified id got chk children dne exception note};
 
@@ -113,7 +113,7 @@ sub render_got {
     return '<UNDEF>' unless defined $got;
 
     my $check = $self->{+CHK};
-    my $stringify = $check && $check->stringify_got;
+    my $stringify = defined( $check ) && $check->stringify_got;
 
     return render_ref($got) if ref $got && !$stringify;
 
@@ -176,7 +176,7 @@ sub _join_id {
 sub should_show {
     my $self = shift;
     return 1 unless $self->verified;
-    my $check = $self->check || return 0;
+    defined( my $check = $self->check ) || return 0;
     return 0 unless $check->lines;
     my $file = $check->file || return 0;
 
@@ -218,7 +218,7 @@ sub table_header { [map {$COLUMNS{$_}->{alias} || $_} @COLUMN_ORDER] }
 sub table_op {
     my $self = shift;
 
-    my $check = $self->{+CHK} || return '!exists';
+    defined( my $check = $self->{+CHK} ) || return '!exists';
 
     return $check->operator($self->{+GOT})
         unless $self->{+DNE} && $self->{+DNE} eq 'got';
@@ -229,7 +229,7 @@ sub table_op {
 sub table_check_lines {
     my $self = shift;
 
-    my $check = $self->{+CHK} || return '';
+    defined( my $check = $self->{+CHK} ) || return '';
     my $lines = $check->lines || return '';
 
     return '' unless @$lines;
@@ -240,7 +240,7 @@ sub table_check_lines {
 sub table_got_lines {
     my $self = shift;
 
-    my $check = $self->{+CHK} || return '';
+    defined( my $check = $self->{+CHK} ) || return '';
     return '' if $self->{+DNE} && $self->{+DNE} eq 'got';
 
     my @lines = $check->got_lines($self->{+GOT});
@@ -497,7 +497,7 @@ Returns all the lines of the table that should be displayed.
 =head1 SOURCE
 
 The source code repository for Test2-Suite can be found at
-F<http://github.com/Test-More/Test2-Suite/>.
+F<https://github.com/Test-More/Test2-Suite/>.
 
 =head1 MAINTAINERS
 
@@ -517,7 +517,7 @@ F<http://github.com/Test-More/Test2-Suite/>.
 
 =head1 COPYRIGHT
 
-Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2018 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
