@@ -2,7 +2,7 @@ package Test2::Mock;
 use strict;
 use warnings;
 
-our $VERSION = '0.000077';
+our $VERSION = '0.000118';
 
 use Carp qw/croak confess/;
 our @CARP_NOT = (__PACKAGE__);
@@ -210,7 +210,7 @@ sub before {
     my ($name, $sub) = @_;
     $self->_check();
     my $orig = $self->current($name);
-    $self->_inject(0, $name => sub { $sub->(@_); $orig->(@_) });
+    $self->_inject({}, $name => sub { $sub->(@_); $orig->(@_) });
 }
 
 sub after {
@@ -218,7 +218,7 @@ sub after {
     my ($name, $sub) = @_;
     $self->_check();
     my $orig = $self->current($name);
-    $self->_inject(0, $name => sub {
+    $self->_inject({}, $name => sub {
         my @out;
 
         my $want = wantarray;
@@ -246,19 +246,25 @@ sub around {
     my ($name, $sub) = @_;
     $self->_check();
     my $orig = $self->current($name);
-    $self->_inject(0, $name => sub { $sub->($orig, @_) });
+    $self->_inject({}, $name => sub { $sub->($orig, @_) });
 }
 
 sub add {
     my $self = shift;
     $self->_check();
-    $self->_inject(1, @_);
+    $self->_inject({add => 1}, @_);
 }
 
 sub override {
     my $self = shift;
     $self->_check();
-    $self->_inject(0, @_);
+    $self->_inject({}, @_);
+}
+
+sub set {
+    my $self = shift;
+    $self->_check();
+    $self->_inject({set => 1}, @_);
 }
 
 sub current {
@@ -347,7 +353,10 @@ sub _parse_inject {
 
 sub _inject {
     my $self = shift;
-    my ($add, @pairs) = @_;
+    my ($params, @pairs) = @_;
+
+    my $add = $params->{add};
+    my $set = $params->{set};
 
     my $class = $self->{+CLASS};
 
@@ -360,7 +369,7 @@ sub _inject {
         my $orig = $self->current("$sig$sym");
 
         croak "Cannot override '$sig$class\::$sym', symbol is not already defined"
-            unless $orig || $add || ($sig eq '&' && $class->can($sym));
+            unless $orig || $add || $set || ($sig eq '&' && $class->can($sym));
 
         # Cannot be too sure about scalars in globs
         croak "Cannot add '$sig$class\::$sym', symbol is already defined"
@@ -510,7 +519,7 @@ the instance is destroyed it will restore the package to its original state.
 
 =over 4
 
-=item $mock = $class->new(class => $CLASS, ...)
+=item $mock = Test2::Mock->new(class => $CLASS, ...)
 
 This will create a new instance of L<Test2::Mock> that manages mocking
 for the specified C<$CLASS>.
@@ -535,11 +544,17 @@ is identical to this:
 
 =item $mock->override('symbol1' => ..., 'symbol2' => ...)
 
+=item $mock->set('symbol1' => ..., 'symbol2' => ...)
+
 C<add()> and C<override()> are the primary ways to add/modify methods for a
 class. Both accept the exact same type of arguments. The difference is that
 C<override> will fail unless the symbol you are overriding already exists,
 C<add> on the other hand will fail if the symbol does already exist.
 
+C<set()> was more recently added for cases where you may not know if the sub
+already exists. These cases are rare, and set should be avoided (think of it
+like 'no strict'). However there are valid use cases, so it was added.
+
 B<Note:> Think of override as a push operation. If you call override on the
 same symbol multiple times it will track that. You can use C<restore()> as a
 pop operation to go back to the previous mock. C<reset> can be used to remove
@@ -749,7 +764,7 @@ Returns the child mock, if any.
 =head1 SOURCE
 
 The source code repository for Test2-Suite can be found at
-F<http://github.com/Test-More/Test2-Suite/>.
+F<https://github.com/Test-More/Test2-Suite/>.
 
 =head1 MAINTAINERS
 
@@ -769,7 +784,7 @@ F<http://github.com/Test-More/Test2-Suite/>.
 
 =head1 COPYRIGHT
 
-Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2018 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
